@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2008 Jaap Karssenberg <pardus@cpan.org>
+# Copyright 2008 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
 '''Zim test suite'''
 
@@ -22,7 +22,7 @@ __all__ = [
 	'export', 'www', 'search',
 	'widgets', 'gui', 'pageview',
 	'calendar', 'printtobrowser', 'versioncontrol', 'inlinecalculator',
-	'tasklist',
+	'tasklist', 'tags',
 	'equationeditor', 'diagrameditor',
 ]
 
