@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2009 Jaap Karssenberg <pardus@cpan.org>
+# Copyright 2009 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
 import tests
 from tests import TestCase
@@ -12,7 +12,7 @@ class TestDiagramEditor(TestCase):
 	slowTest = True
 
 	@classmethod
-	def skipTest(klass):
+	def skipTestZim(klass):
 		if not InsertDiagramPlugin.check_dependencies_ok():
 			return 'Missing dependencies'
 		else:
