@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2009 Jaap Karssenberg <pardus@cpan.org>
+# Copyright 2009 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
 from tests import TestCase, MockObject, create_tmp_dir, get_test_notebook, get_test_data
 
@@ -24,11 +24,11 @@ class TestLinker(TestCase):
 		linker.set_path(Path('foo:bar')) # normally set by exporter
 		linker.set_base(Dir('/source/dir/foo')) # normally set by exporter
 
-		self.assertEqual(linker.page('+dus'), './bar/dus.html')
-		self.assertEqual(linker.page('dus'), './dus.html')
-		self.assertEqual(linker.file('./dus.pdf'), './bar/dus.pdf')
-		self.assertEqual(linker.file('../dus.pdf'), './dus.pdf')
-		self.assertEqual(linker.file('../../dus.pdf'), '../dus.pdf')
+		self.assertEqual(linker.link_page('+dus'), './bar/dus.html')
+		self.assertEqual(linker.link_page('dus'), './dus.html')
+		self.assertEqual(linker.link_file('./dus.pdf'), './bar/dus.pdf')
+		self.assertEqual(linker.link_file('../dus.pdf'), './dus.pdf')
+		self.assertEqual(linker.link_file('../../dus.pdf'), '../dus.pdf')
 
 
 class TestExport(TestCase):
