@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2009 Jaap Karssenberg <pardus@cpan.org>
+# Copyright 2009 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
 '''This module contains utilities to work with config files. It also supports looking up
 files according to the Freedesktop.org (XDG) Base Dir specification.
@@ -354,7 +354,12 @@ class ListDict(dict):
 		AssertionError. )
 
 		If 'check' is given and is a set the value will be tested
-		against this set.
+		against this set. If 'check' is a list or a tuple and the
+		default is not an int it is also considered a set.
+
+		If the default is an integer and 'check' is a tuple of two
+		integers, the check will be that the value is in this range.
+		(For compatibility with InputForm.add_inputs arguments.)
 
 		If 'allow_empty' is True values are also allowed to be empty
 		string or None. This is used for optional parameters in the
@@ -402,7 +407,8 @@ class ListDict(dict):
 					self.__setitem__(key, default)
 			else:
 				pass # value is OK
-		elif isinstance(check, set):
+		elif isinstance(check, (set, list)) \
+		or (isinstance(check, tuple) and not isinstance(default, int)):
 			if not (allow_empty and default in ('', None)):
 				assert default in check, 'Default is not within allows set'
 
@@ -413,6 +419,22 @@ class ListDict(dict):
 				self.__setitem__(key, default)
 			else:
 				pass # value is OK
+		elif isinstance(check, tuple) and isinstance(default, int):
+			assert len(check) == 2 \
+				and isinstance(check[0], int) \
+				and isinstance(check[1], int)
+			if not isinstance(self[key], int):
+				logger.warn(
+					'Invalid config value for %s: "%s" - should be integer',
+					key, self[key])
+				self.__setitem__(key, default)
+			elif not check[0] <= self[key] <= check[1]:
+				logger.warn(
+					'Invalid config value for %s: "%s" - should be between %i and %i',
+					key, self[key], check[0], check[1])
+				self.__setitem__(key, default)
+			else:
+				pass # value is OK
 		else: # assume callable
 			modified = self.modified
 			try:
@@ -455,6 +477,14 @@ class ConfigDict(ListDict):
 	These are represented as INI files where each sub-dict is a section.
 	Sections are auto-vivicated when getting a non-existing key.
 	Each section is in turn a ListDict.
+
+	By default sections will be merged if they have the same name.
+	Values that appear under the same section name later in the file
+	will overwrite values that appeared earlier.
+
+	As a special case we can support sections that repeat under the
+	same section name. To do this assign the section name a list
+	before parsing.
 	'''
 
 	def __getitem__(self, k):
@@ -463,7 +493,9 @@ class ConfigDict(ListDict):
 		return dict.__getitem__(self, k)
 
 	def parse(self, text):
-		'''Parse 'text' and set values based on this input'''
+		'''Parse 'text' and set values based on this input
+		@param text: a string or a list of lines
+		'''
 		# Note that we explicitly do _not_ support comments on the end
 		# of a line. This is because "#" could be a valid character in
 		# a config value.
@@ -477,6 +509,9 @@ class ConfigDict(ListDict):
 			elif line.startswith('[') and line.endswith(']'):
 				name = line[1:-1].strip()
 				section = self[name]
+				if isinstance(section, list):
+					section.append(ListDict())
+					section = section[-1]
 			elif '=' in line:
 				parameter, value = line.split('=', 1)
 				parameter = str(parameter.rstrip()) # no unicode
@@ -515,12 +550,20 @@ class ConfigDict(ListDict):
 		dict. Used to write as a config file.
 		'''
 		lines = []
+		def dump_section(name, parameters):
+			lines.append('[%s]\n' % section)
+			for param, value in parameters.items():
+				lines.append('%s=%s\n' % (param, self._encode_value(value)))
+			lines.append('\n')
+
 		for section, parameters in self.items():
 			if parameters:
-				lines.append('[%s]\n' % section)
-				for param, value in parameters.items():
-					lines.append('%s=%s\n' % (param, self._encode_value(value)))
-				lines.append('\n')
+				if isinstance(parameters, list):
+					for param in parameters:
+						dump_section(section, param)
+				else:
+					dump_section(section, parameters)
+
 		return lines
 
 	def _encode_value(self, value):
