@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2009 Jaap Karssenberg <pardus@cpan.org>
+# Copyright 2009 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
 # The Error class needed to be put in a separate file to avoid recusive
 # imports.
@@ -24,7 +24,7 @@ class Error(Exception):
 	user should be translated.
 	'''
 
-	description = 'Unspecified error...'
+	description = ''
 
 	def __init__(self, msg):
 		self.msg = msg
@@ -41,3 +41,9 @@ class Error(Exception):
 
 	def __repr__(self):
 		return '<%s>' % self.__class__.__name__
+
+
+class TrashNotSupportedError(Error):
+	# Defined here because this is not specific to files, but can occur
+	# in different storage models as well
+	pass
